<?php
/**
 * Copyright © 2015 Infomodus. All rights reserved.
 */

// @codingStandardsIgnoreFile

namespace Infomodus\Upslabel\Block\Adminhtml\Items\Edit\Tab;


use Magento\Backend\Block\Widget\Form\Generic;
use Magento\Backend\Block\Widget\Tab\TabInterface;


class Package extends Generic implements TabInterface
{

    /**
     * {@inheritdoc}
     */
    public function getTabLabel()
    {
        return __('Package Information');
    }

    /**
     * {@inheritdoc}
     */
    public function getTabTitle()
    {
        return __('Package Information');
    }

    /**
     * {@inheritdoc}
     */
    public function canShowTab()
    {
        return true;
    }

    /**
     * {@inheritdoc}
     */
    public function isHidden()
    {
        return false;
    }

    /**
     * Prepare form before rendering HTML
     *
     * @return $this
     * @SuppressWarnings(PHPMD.NPathComplexity)
     * @SuppressWarnings(PHPMD.ExcessiveMethodLength)
     */
    protected function _prepareForm()
    {
        $model = $this->_coreRegistry->registry('current_infomodus_upslabel_items');
        /** @var \Magento\Framework\Data\Form $form */
        $form = $this->_formFactory->create();
        $form->setHtmlIdPrefix('item_');
        foreach ($model['handy']->defPackageParams AS $key => $package) {
            $fieldset = $form->addFieldset('package_fieldset_' . $key . '_', ['legend' => __('Package') . (" <span class=\"replace-number\">" . ($key + 1) . "</span>")]);
            $fieldset->addField(
                'packagingtypecode_' . $key . '_',
                'select',
                ['name' => 'package[packagingtypecode][]',
                    'label' => __('Packaging Type Code'),
                    'title' => __('Packaging Type Code'),
                    'required' => true,
                    'options' => $model['handy']->objectManager->get('Infomodus\Upslabel\Model\Config\Upspackagecode')->getPackagingtypecode(),
                    'value' => $package['packagingtypecode']
                ]
            );
            $fieldset->addField(
                'packagingdescription_' . $key . '_',
                'text',
                ['name' => 'package[packagingdescription][]',
                    'label' => __('Packaging Description'),
                    'title' => __('Packaging Description'),
                    'required' => true,
                    'value' => $package['packagingdescription']
                ]
            );
            $fieldset->addField(
                'packagingreferencenumbercode_' . $key . '_',
                'text',
                ['name' => 'package[packagingreferencenumbercode][]',
                    'label' => __('Packaging Reference Number Code'),
                    'title' => __('Packaging Reference Number Code'),
                    'required' => false,
                    'value' => $package['packagingreferencenumbercode']
                ]
            );
            $fieldset->addField(
                'packagingreferencenumbervalue_' . $key . '_',
                'text',
                ['name' => 'package[packagingreferencenumbervalue][]',
                    'label' => __('Packaging Reference Number Value'),
                    'title' => __('Packaging Reference Number Value'),
                    'required' => false,
                    'value' => $package['packagingreferencenumbervalue']
                ]
            );
            $fieldset->addField(
                'packagingreferencenumbercode2_' . $key . '_',
                'text',
                ['name' => 'package[packagingreferencenumbercode2][]',
                    'label' => __('Packaging Reference Number Code 2'),
                    'title' => __('Packaging Reference Number Code 2'),
                    'required' => false,
                    'value' => $package['packagingreferencenumbercode2']
                ]
            );
            $fieldset->addField(
                'packagingreferencenumbervalue2_' . $key . '_',
                'text',
                ['name' => 'package[packagingreferencenumbervalue2][]',
                    'label' => __('Packaging Reference Number Value 2'),
                    'title' => __('Packaging Reference Number Value 2'),
                    'required' => false,
                    'value' => $package['packagingreferencenumbervalue2']
                ]
            );
            $fieldset->addField(
                'weight_' . $key . '_',
                'text',
                ['name' => 'package[weight][]',
                    'label' => __('Weight'),
                    'title' => __('Weight'),
                    'required' => true,
                    'value' => $package['weight']
                ]
            );
            $fieldset->addField(
                'packweight_' . $key . '_',
                'text',
                ['name' => 'package[packweight][]',
                    'label' => __('Pack weight'),
                    'title' => __('Pack weight'),
                    'required' => false,
                    'value' => $package['packweight']
                ]
            );
            $fieldset->addField(
                'additionalhandling_' . $key . '_',
                'select',
                ['name' => 'package[additionalhandling][]',
                    'label' => __('Additional Handling'),
                    'title' => __('Additional Handling'),
                    'required' => false,
                    'options' => [__('No'), __('Yes')],
                    'value' => $package['additionalhandling']
                ]
            );
            $fieldset->addField(
                'dimansion_id_' . $key . '_',
                'select',
                ['name' => 'package[dimansion_id][]',
                    'label' => __('Package Dimensions'),
                    'title' => __('Package Dimensions'),
                    'required' => false,
                    'options' => $model['handy']->objectManager->get('Infomodus\Upslabel\Model\Config\Defaultdimensionsset')->getDimensionSets(),
                    'value' => $package['dimansion_id']
                ]
            );
            $fieldset->addField(
                'length_' . $key . '_',
                'text',
                ['name' => 'package[length][]',
                    'label' => __('Length'),
                    'title' => __('Length'),
                    'required' => false,
                    'value' => $package['length']
                ]
            );
            $fieldset->addField(
                'width_' . $key . '_',
                'text',
                ['name' => 'package[width][]',
                    'label' => __('Width'),
                    'title' => __('Width'),
                    'required' => false,
                    'value' => $package['width']
                ]
            );
            $fieldset->addField(
                'height_' . $key . '_',
                'text',
                ['name' => 'package[height][]',
                    'label' => __('Height'),
                    'title' => __('Height'),
                    'required' => false,
                    'value' => $package['height']
                ]
            );
            if ($model['handy']->type != 'refund') {
                $fieldset->addField(
                    'cod_' . $key . '_',
                    'select',
                    ['name' => 'package[cod][]',
                        'label' => __('COD'),
                        'title' => __('COD'),
                        'required' => false,
                        'options' => [__('No'), __('Yes')],
                        'value' => $package['cod']
                    ]
                );
                $fieldset->addField(
                    'codfundscode_' . $key . '_',
                    'select',
                    ['name' => 'package[codfundscode][]',
                        'label' => __('COD Funds code'),
                        'title' => __('COD Funds code'),
                        'required' => false,
                        'options' => [0 => __('check, cashiers check or money order - no cash allowed'), 8 => __('cashiers check or money order - no cash allowed')],
                        'value' => $package['codfundscode']
                    ]
                );
            }
            $fieldset->addField(
                'codmonetaryvalue_' . $key . '_',
                'text',
                ['name' => 'package[codmonetaryvalue][]',
                    'label' => __('Monetary value'),
                    'title' => __('Monetary value'),
                    'required' => false,
                    'value' => $package['codmonetaryvalue']
                ]
            );
            $fieldset->addField(
                'insuredmonetaryvalue_' . $key . '_',
                'text',
                ['name' => 'package[insuredmonetaryvalue][]',
                    'label' => __('Insured Monetary value'),
                    'title' => __('Insured Monetary value'),
                    'required' => false,
                    'value' => $package['insuredmonetaryvalue']
                ]
            );
        }
        /*$form->setValues($model->getData());*/
        $this->setForm($form);
        return parent::_prepareForm();
    }
}
