<?php
/**
 * Copyright © 2015 Infomodus. All rights reserved.
 */

namespace Infomodus\Upslabel\Controller\Adminhtml\Pdflabels;

class Many extends \Infomodus\Upslabel\Controller\Adminhtml\Pdflabels\AbstractMassAction
{
    protected $_conf;
    protected $_pdf;
    protected $collectionFactory;
    protected $shipmentCollectionFactory;
    protected $creditmemoCollectionFactory;
    protected $labelCollectionFactory;
    protected $fileFactory;

    public function __construct(
        \Magento\Ui\Component\MassAction\Filter $filter,
        \Magento\Framework\Registry $registry,
        \Magento\Backend\App\Action\Context $context,
        \Magento\Sales\Model\ResourceModel\Order\CollectionFactory $collectionFactory,
        \Magento\Sales\Model\ResourceModel\Order\Shipment\CollectionFactory $shipmentCollectionFactory,
        \Magento\Sales\Model\ResourceModel\Order\Creditmemo\CollectionFactory $creditmemoCollectionFactory,
        \Infomodus\Upslabel\Model\Resource\Items\CollectionFactory $labelCollectionFactory,
        \Magento\Framework\App\Response\Http\FileFactory $fileFactory,
        \Infomodus\Upslabel\Helper\Config $conf,
        \Infomodus\Upslabel\Helper\Pdf $pdf
    )
    {
        $this->_conf = $conf;
        $this->_pdf = $pdf;
        $this->collectionFactory = $collectionFactory;
        $this->shipmentCollectionFactory = $shipmentCollectionFactory;
        $this->creditmemoCollectionFactory = $creditmemoCollectionFactory;
        $this->labelCollectionFactory = $labelCollectionFactory;
        $this->fileFactory = $fileFactory;
        parent::__construct($context, $filter);
    }

    protected function massAction(\Magento\Framework\Model\ResourceModel\Db\Collection\AbstractCollection $collection)
    {
        $ids = $collection->getAllIds();
        if (count($ids) > 0) {
            $labels = $this->_conf->objectManager->get('Infomodus\Upslabel\Model\Items')->getCollection()->addFieldToFilter('lstatus', 0);
            if ($this->_conf->getStoreConfig('upslabel/printing/bulk_printing_all') == 1) {
                $labels->addFieldToFilter('rva_printed', 0);
            }
            switch ($this->getRequest()->getParam('namespace')) {
                case 'sales_order_grid':
                    $labels->addFieldToFilter('order_id', ['in' => $ids]);
                    $errorLink = 'sales/order';
                    break;
                case 'sales_order_shipment_grid':
                    $labels->addFieldToFilter('shipment_id', ['in' => $ids])->addFieldToFilter('type', 'shipment');
                    $errorLink = 'sales/shipment';
                    break;
                case 'sales_order_creditmemo_grid':
                    $labels->addFieldToFilter('shipment_id', ['in' => $ids])->addFieldToFilter('type', 'refund');
                    $errorLink = 'sales/creditmemo';
                    break;
                default:
                    $labels->addFieldToFilter('upslabel_id', ['in' => $ids]);
                    $errorLink = 'infomodus_upslabel/items';
                    break;
            }
            if (count($labels) > 0) {
                $data = $this->_pdf->createManyPDF($labels);
                if ($data !== FALSE) {
                    return $this->fileFactory->create(
                        'ups_shipping_labels.pdf',
                        $data->render(),
                        \Magento\Framework\App\Filesystem\DirectoryList::VAR_DIR,
                        'application/pdf'
                    );
                }
            }
            else {
                $this->messageManager->addError(__('For the selected items are not created labels.'));
                return $this->resultRedirectFactory->create()->setPath($errorLink.'/');
            }
        }
    }
}
