<?php
/**
 * Copyright © 2015 Infomodus. All rights reserved.
 */

namespace Infomodus\Upslabel\Plugin;

class AddToolbarButtons extends \Infomodus\Upslabel\Helper\Config
{
    protected $_context;
    public function beforePushButtons(
        \Magento\Backend\Block\Widget\Button\Toolbar $subject,
        \Magento\Framework\View\Element\AbstractBlock $context,
        \Magento\Backend\Block\Widget\Button\ButtonList $buttonList
    )
    {
        $this->_context = $context;
        if ($context instanceof \Magento\Sales\Block\Adminhtml\Order\View) {
            $context->getToolbar()->addChild(
                'create_ups_labels',
                'Magento\Backend\Block\Widget\Button\SplitButton',
                [
                    'label' => __('Create UPS label'),
                    'class_name' => 'Magento\Backend\Block\Widget\Button\SplitButton',
                    'button_class' => 'widget-button-save',
                    'options' => $this->_getOrderButtonOptions()
                ]
            );
            $labels = $this->objectManager->get('Infomodus\Upslabel\Model\Items')->getCollection()->addFieldToFilter('order_id', $this->_context->getRequest()->getParam('order_id'));
            if(count($labels) > 0) {
                $buttonList->add(
                    'show_ups_labels',
                    [
                        'label' => __('Show UPS label(s)'),
                        'class' => 'primary',
                        'onclick' => 'setLocation("' . $this->_context->getUrl('infomodus_upslabel/items/show', ['order_id' => $this->_context->getRequest()->getParam('order_id'), 'redirect_path'=> 'order']) . '")',
                    ]
                );
            }
        }
        if ($context instanceof \Magento\Shipping\Block\Adminhtml\View) {
            $shipment = $this->objectManager->get('Magento\Sales\Model\Order\Shipment')->load($this->_context->getRequest()->getParam('shipment_id'));
            $buttonList->add(
                'create_ups_labels',
                [
                    'label' => __('Create UPS label'),
                    'class' => 'primary',
                    'onclick' => 'setLocation("' . $this->_context->getUrl('infomodus_upslabel/items/edit', ['order_id' => $shipment->getOrderId(), 'shipment_id' => $this->_context->getRequest()->getParam('shipment_id'), 'direction' => 'shipment', 'redirect_path'=> 'shipment']) . '")',
                ]
            );
            $labels = $this->objectManager->get('Infomodus\Upslabel\Model\Items')->getCollection()
                ->addFieldToFilter('order_id', $shipment->getOrderId())
                ->addFieldToFilter('shipment_id', $this->_context->getRequest()->getParam('shipment_id'));
            if(count($labels) > 0) {
                $buttonList->add(
                    'show_ups_labels',
                    [
                        'label' => __('Show UPS label(s)'),
                        'class' => 'primary',
                        'onclick' => 'setLocation("' . $this->_context->getUrl('infomodus_upslabel/items/show', ['order_id' => $shipment->getOrderId(), 'shipment_id' => $this->_context->getRequest()->getParam('shipment_id'), 'type' => 'shipment', 'redirect_path'=> 'shipment']) . '")',
                    ]
                );
            }
        }
        if ($context instanceof \Magento\Sales\Block\Adminhtml\Order\Creditmemo\View) {
            $shipment = $this->objectManager->get('Magento\Sales\Model\Order\Creditmemo')->load($this->_context->getRequest()->getParam('creditmemo_id'));
            $buttonList->add(
                'create_ups_labels',
                [
                    'label' => __('Create UPS label'),
                    'class' => 'primary',
                    'onclick' => 'setLocation("' . $this->_context->getUrl('infomodus_upslabel/items/edit', ['order_id' => $shipment->getOrderId(), 'shipment_id' => $this->_context->getRequest()->getParam('creditmemo_id'), 'direction' => 'refund', 'redirect_path'=> 'creditmemo']) . '")',
                ]
            );
            $labels = $this->objectManager->get('Infomodus\Upslabel\Model\Items')->getCollection()
                ->addFieldToFilter('order_id', $shipment->getOrderId())
                ->addFieldToFilter('shipment_id', $this->_context->getRequest()->getParam('shipment_id'));
            if(count($labels) > 0) {
                $buttonList->add(
                    'show_ups_labels',
                    [
                        'label' => __('Show UPS label(s)'),
                        'class' => 'primary',
                        'onclick' => 'setLocation("' . $this->_context->getUrl('infomodus_upslabel/items/show', ['order_id' => $shipment->getOrderId(), 'shipment_id' => $this->_context->getRequest()->getParam('creditmemo_id'), 'type' => 'creditmemo', 'redirect_path'=> 'creditmemo']) . '")',
                    ]
                );
            }
        }
        return [$context, $buttonList];
    }

    protected function _getOrderButtonOptions()
    {
        $options = [];
        $options[] = [
            'id' => 'create_ups_label_direct',
            'label' => __('Shipping UPS label'),
            'onclick' => 'setLocation("' . $this->_context->getUrl('infomodus_upslabel/items/edit', ['order_id' => $this->_context->getRequest()->getParam('order_id'), 'direction' => 'shipment', 'redirect_path'=> 'order']) . '")',
            'default' => true,
        ];
        $options[] = [
            'id' => 'create_ups_label_return',
            'label' => __('RMA(return) UPS label'),
            'onclick' => 'setLocation("' . $this->_context->getUrl('infomodus_upslabel/items/edit', ['order_id' => $this->_context->getRequest()->getParam('order_id'), 'direction' => 'refund', 'redirect_path'=> 'order']) . '")',
        ];
        $options[] = [
            'id' => 'create_ups_label_invert',
            'label' => __('Invert UPS label'),
            'onclick' => 'setLocation("' . $this->_context->getUrl('infomodus_upslabel/items/edit', ['order_id' => $this->_context->getRequest()->getParam('order_id'), 'direction' => 'invert', 'redirect_path'=> 'order']) . '")',
        ];
        return $options;
    }
}